@@ -1,3 +1,3 @@
 from . import epix
 from . import gpas
-from .model import Identity
+from .model import Identity, Contact
