@@ -1,4 +1,3 @@
-import functools
 from typing import List, Any
 from urllib.parse import urljoin
 
@@ -135,9 +134,50 @@ class EPIXClient:
 
         :param base_url: URL where the E-PIX service is hosted
         """
-        client = create_epix_client(base_url)
-        self.resolve_person_for_mpi = functools.partial(resolve_person_for_mpi, client)
-        self.request_mpi_batch = functools.partial(request_mpi_batch, client)
-        self.get_mpis_in_domain = functools.partial(get_identity_ids_in_domain, client)
-        self.delete_identity = functools.partial(delete_identity, client)
-        self.deactivate_identity = functools.partial(deactivate_identity, client)
+        self.client = create_epix_client(base_url)
+
+    def request_mpi_batch(self, domain: str, source: str, identities: List[Identity]) -> List[str]:
+        """
+        Submits many identities to the MPI for creation. Returns the identifiers assigned to these identities.
+
+        :param domain: Data domain
+        :param source: Data source
+        :param identities: Identities to insert
+        :return: List of identifiers
+        """
+        return request_mpi_batch(self.client, domain, source, identities)
+
+    def get_identity_ids_in_domain(self, domain: str) -> List[int]:
+        """
+        Fetches all identity IDs present in the given domain.
+
+        :param domain: Data domain
+        :return: List of identity IDs
+        """
+        return get_identity_ids_in_domain(self.client, domain)
+
+    def delete_identity(self, identity_id: int) -> None:
+        """
+        Deletes the identity with the given ID.
+
+        :param identity_id: ID of the identity to delete
+        """
+        return delete_identity(self.client, identity_id)
+
+    def deactivate_identity(self, identity_id: int) -> None:
+        """
+        Deactivates the identity with the given ID.
+
+        :param identity_id: ID of the identity to deactivate
+        """
+        return deactivate_identity(self.client, identity_id)
+
+    def resolve_person_for_mpi(self, domain: str, mpi: str) -> Identity:
+        """
+        Looks up an identifier in the MPI and returns the corresponding personal entry, if present.
+
+        :param domain: Data domain
+        :param mpi: MPI record identifier
+        :return: Personal data associated with the given identifier
+        """
+        return resolve_person_for_mpi(self.client, domain, mpi)
